#!/usr/bin/env python
#
# Performs a release of Review Board. This can only be run by the core
# developers with release permissions.
#

import os
import re
import sys

sys.path.insert(0, "..")
from reviewboard import get_package_version


PY_VERSIONS = ["2.4", "2.5"]

LATEST_PY_VERSION = PY_VERSIONS[-1]

RELEASES_URL = \
    "review-board.org:/var/www/downloads.review-board.org/htdocs/releases/"

SVN_URL = "https://reviewboard.googlecode.com/svn"
PROJECT_URL = "%s/trunk/reviewboard" % SVN_URL
TAG_URL = "%s/releases/reviewboard/%s" % (SVN_URL, get_package_version())


built_files = []


def execute(cmdline):
    print ">>> %s" % cmdline
    if os.system(cmdline) != 0:
        print "!!! Error invoking command."
        sys.exit(1)


def run_setup(target, pyver = LATEST_PY_VERSION):
    execute("python%s ./setup.py release %s" % (pyver, target))


def build_targets():
    for pyver in PY_VERSIONS:
        run_setup("bdist_egg", pyver)
        built_files.append("dist/ReviewBoard-%s-py%s.egg" %
                           (get_package_version(), pyver))

    run_setup("sdist")
    built_files.append("dist/ReviewBoard-%s.tar.gz" % get_package_version())


def upload_files():
    execute("scp %s %s" % (" ".join(built_files), RELEASES_URL))


def tag_release():
    execute("svn cp %s %s" % (PROJECT_URL, TAG_URL))


def register_release():
    run_setup("register")


def main():
    if not os.path.exists("setup.py"):
        sys.stderr.write("This must be run from the root of the "
                         "Review Board tree.\n")
        sys.exit(1)

    build_targets()
    upload_files()
    tag_release()
    register_release()


if __name__ == "__main__":
    main()
